from .initialise import init
from .ansi import Fore, Back, Style
from .ansitowin32 import AnsiToWin32

__version__ = '0.1.7'

